export function decodeGradientColors(input: any, opts: any): {
    color_mode: string;
    colors: any;
    segments: number;
    offset: number;
    brightness: number;
    on: boolean;
    x?: undefined;
    y?: undefined;
    name?: undefined;
    color_temp?: undefined;
} | {
    color_mode: string;
    x: number;
    y: number;
    brightness: number;
    on: boolean;
    colors?: undefined;
    segments?: undefined;
    offset?: undefined;
    name?: undefined;
    color_temp?: undefined;
} | {
    color_mode: string;
    x: number;
    y: number;
    brightness: number;
    on: boolean;
    name: any;
    colors?: undefined;
    segments?: undefined;
    offset?: undefined;
    color_temp?: undefined;
} | {
    color_mode: string;
    color_temp: number;
    brightness: number;
    on: boolean;
    colors?: undefined;
    segments?: undefined;
    offset?: undefined;
    x?: undefined;
    y?: undefined;
    name?: undefined;
} | {
    brightness: number;
    on: boolean;
    color_mode?: undefined;
    colors?: undefined;
    segments?: undefined;
    offset?: undefined;
    x?: undefined;
    y?: undefined;
    name?: undefined;
    color_temp?: undefined;
} | {
    color_mode?: undefined;
    colors?: undefined;
    segments?: undefined;
    offset?: undefined;
    brightness?: undefined;
    on?: undefined;
    x?: undefined;
    y?: undefined;
    name?: undefined;
    color_temp?: undefined;
};
export function encodeGradientColors(value: any, opts: any): string;
export namespace extend {
    function light_onoff_brightness(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    function light_onoff_brightness_colortemp(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    function light_onoff_brightness_color(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    function light_onoff_brightness_colortemp_color(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    function light_onoff_brightness_colortemp_color_gradient(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
}
declare namespace philipsTz {
    namespace gradient_scene {
        const key: string[];
        function convertSet(entity: any, key: any, value: any, meta: any): Promise<void>;
    }
    function gradient(opts?: {
        reverse: boolean;
    }): {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    };
    namespace effect {
        const key_1: string[];
        export { key_1 as key };
        export function convertSet_1(entity: any, key: any, value: any, meta: any): Promise<void>;
        export { convertSet_1 as convertSet };
    }
    namespace hue_power_on_behavior {
        const key_2: string[];
        export { key_2 as key };
        export function convertSet_2(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                hue_power_on_behavior: any;
            };
        }>;
        export { convertSet_2 as convertSet };
    }
    namespace hue_power_on_error {
        const key_3: string[];
        export { key_3 as key };
        export function convertSet_3(entity: any, key: any, value: any, meta: any): Promise<void>;
        export { convertSet_3 as convertSet };
    }
    namespace hue_motion_sensitivity {
        const key_4: string[];
        export { key_4 as key };
        export function convertSet_4(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                motion_sensitivity: any;
            };
        }>;
        export { convertSet_4 as convertSet };
        export function convertGet(entity: any, key: any, meta: any): Promise<void>;
    }
    namespace hue_motion_led_indication {
        const key_5: string[];
        export { key_5 as key };
        export function convertSet_5(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                led_indication: any;
            };
        }>;
        export { convertSet_5 as convertSet };
        export function convertGet_1(entity: any, key: any, meta: any): Promise<void>;
        export { convertGet_1 as convertGet };
    }
}
declare namespace philipsFz {
    export namespace hue_tap_dial {
        const cluster: string;
        const type: string;
        const options: exposes.Composite[];
        function convert(model: any, msg: any, publish: any, options: any, meta: any): {
            action: string;
            brightness: any;
            action_duration: number;
        };
    }
    export function gradient_1(opts?: {
        reverse: boolean;
    }): {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            gradient: any;
        } | {
            gradient?: undefined;
        };
    };
    export { gradient_1 as gradient };
}
export const gradientScenes: {
    blossom: string;
    crocus: string;
    precious: string;
    narcissa: string;
    beginnings: string;
    first_light: string;
    horizon: string;
    valley_dawn: string;
    sunflare: string;
    emerald_flutter: string;
    memento: string;
    resplendent: string;
    scarlet_dream: string;
    lovebirds: string;
    smitten: string;
    glitz_and_glam: string;
    promise: string;
    ruby_romance: string;
    city_of_love: string;
    honolulu: string;
    savanna_sunset: string;
    golden_pond: string;
    runy_glow: string;
    tropical_twilight: string;
    miami: string;
    cancun: string;
    rio: string;
    chinatown: string;
    ibiza: string;
    osaka: string;
    tokyo: string;
    motown: string;
    fairfax: string;
    galaxy: string;
    starlight: string;
    'blood moon': string;
    artic_aurora: string;
    moonlight: string;
    nebula: string;
    sundown: string;
    blue_lagoon: string;
    palm_beach: string;
    lake_placid: string;
    mountain_breeze: string;
    lake_mist: string;
    ocean_dawn: string;
    frosty_dawn: string;
    sunday_morning: string;
    emerald_isle: string;
    spring_blossom: string;
    midsummer_sun: string;
    autumn_gold: string;
    spring_lake: string;
    winter_mountain: string;
    midwinter: string;
    amber_bloom: string;
    lily: string;
    painted_sky: string;
    winter_beauty: string;
    orange_fields: string;
    forest_adventure: string;
    blue_planet: string;
    soho: string;
    vapor_wave: string;
    magneto: string;
    tyrell: string;
    disturbia: string;
    hal: string;
    golden_star: string;
    under_the_tree: string;
    silent_night: string;
    rosy_sparkle: string;
    festive_fun: string;
    colour_burst: string;
    crystalline: string;
};
export const knownEffects: {
    '0180': string;
    '0280': string;
    '0380': string;
    '0980': string;
    '0a80': string;
};
import exposes = require("./exposes");
export { philipsTz as tz, philipsFz as fz };
//# sourceMappingURL=philips.d.ts.map